;; Generated package description from flymake-proselint.el  -*- no-byte-compile: t -*-
(define-package "flymake-proselint" "0.3.0.0.20221119.52048" "Flymake backend for proselint" '((emacs "27.1")) :commit "aea3a00ec898bc46b56266e77bf1060950d5f765" :authors '(("Manuel Uberti" . "manuel.uberti@inventati.org")) :maintainer '("Manuel Uberti" . "~manuel-uberti/flymake-proselint@lists.sr.ht") :keywords '("convenience") :url "https://git.sr.ht/~manuel-uberti/flymake-proselint")
